from setuptools import find_packages, setup
setup(
    name='cristian_lib',
    version='0.0.1',
    author='Cristian Iordache',
    author_email='iordachecristian000@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    description='A nice library'
)

